@@ -9,23 +9,17 @@ from nitrokeyapp.worker import Worker
 
 class DeviceView(Protocol):
     @property
-    def common_ui(self) -> CommonUi:
-        ...
+    def common_ui(self) -> CommonUi: ...
 
     @property
-    def title(self) -> str:
-        ...
+    def title(self) -> str: ...
 
     @property
-    def widget(self) -> QWidget:
-        ...
+    def widget(self) -> QWidget: ...
 
     @property
-    def worker(self) -> Optional[Worker]:
-        ...
+    def worker(self) -> Optional[Worker]: ...
 
-    def reset(self) -> None:
-        ...
+    def reset(self) -> None: ...
 
-    def refresh(self, data: DeviceData) -> None:
-        ...
+    def refresh(self, data: DeviceData) -> None: ...
