@@ -45,11 +45,7 @@ SETTINGS: Dict[State, Dict] = {
         + "key cryptography to provide strong authentication and "
         + "protect against phishing and other security threats.",
     },
-    State.FidoPin: {
-        "parent": State.Fido,
-        "icon": PIN_ICON,
-        "name": "Pin Change",
-    },
+    State.FidoPin: {"parent": State.Fido, "icon": PIN_ICON, "name": "Pin Change"},
     State.FidoReset: {
         "parent": State.Fido,
         "icon": RESET_ICON,
@@ -69,17 +65,12 @@ SETTINGS: Dict[State, Dict] = {
         + "be stored and managed. Supported are: Plain usernames using a "
         + "password, HOTPs, TOTPs, ReverseHOTPs and HMAC.",
     },
-    State.PasswordsPin: {
-        "parent": State.Passwords,
-        "icon": PIN_ICON,
-        "name": "Pin Change",
-    },
+    State.PasswordsPin: {"parent": State.Passwords, "icon": PIN_ICON, "name": "Pin Change"},
     State.PasswordsReset: {
         "parent": State.Passwords,
         "icon": RESET_ICON,
         "name": "Factory Reset",
-        "desc": "This operation will unevitably remove all your credentials "
-        + "in Passwords!",
+        "desc": "This operation will unevitably remove all your credentials " + "in Passwords!",
     },
 }
 
@@ -196,38 +187,20 @@ class SettingsTab(QtUtilsMixIn, QWidget):
         icon_false = self.get_qicon("close.svg")
 
         loc = QLineEdit.ActionPosition.TrailingPosition
-        self.action_current_password_show = self.ui.current_password.addAction(
-            icon_visibility, loc
-        )
-        self.action_current_password_show.triggered.connect(
-            self.act_current_password_show
-        )
+        self.action_current_password_show = self.ui.current_password.addAction(icon_visibility, loc)
+        self.action_current_password_show.triggered.connect(self.act_current_password_show)
 
-        self.action_new_password_show = self.ui.new_password.addAction(
-            icon_visibility, loc
-        )
+        self.action_new_password_show = self.ui.new_password.addAction(icon_visibility, loc)
         self.action_new_password_show.triggered.connect(self.act_new_password_show)
 
-        self.action_repeat_password_show = self.ui.repeat_password.addAction(
-            icon_visibility, loc
-        )
-        self.action_repeat_password_show.triggered.connect(
-            self.act_repeat_password_show
-        )
+        self.action_repeat_password_show = self.ui.repeat_password.addAction(icon_visibility, loc)
+        self.action_repeat_password_show.triggered.connect(self.act_repeat_password_show)
 
-        self.show_current_password_check = self.ui.current_password.addAction(
-            icon_check, loc
-        )
-        self.show_current_password_false = self.ui.current_password.addAction(
-            icon_false, loc
-        )
+        self.show_current_password_check = self.ui.current_password.addAction(icon_check, loc)
+        self.show_current_password_false = self.ui.current_password.addAction(icon_false, loc)
 
-        self.show_repeat_password_check = self.ui.repeat_password.addAction(
-            icon_check, loc
-        )
-        self.show_repeat_password_false = self.ui.repeat_password.addAction(
-            icon_false, loc
-        )
+        self.show_repeat_password_check = self.ui.repeat_password.addAction(icon_check, loc)
+        self.show_repeat_password_false = self.ui.repeat_password.addAction(icon_false, loc)
 
         self.action_current_password_show.setVisible(False)
         self.action_new_password_show.setVisible(False)
@@ -355,8 +328,7 @@ class SettingsTab(QtUtilsMixIn, QWidget):
         self.ui.btn_save.hide()
 
         self.ui.warning_label.setText(
-            "**Reset for FIDO2 is only possible 10secs "
-            + "after plugging in the device.**"
+            "**Reset for FIDO 2 is only possible within 10secs after plugging in the device.**"
         )
 
         if state == State.FidoReset:
@@ -441,12 +413,7 @@ class SettingsTab(QtUtilsMixIn, QWidget):
         self.action_repeat_password_show.setIcon(icon)
 
     def set_device_data(
-        self,
-        path: str,
-        uuid: str,
-        version: str,
-        variant: str,
-        init_status: str,
+        self, path: str, uuid: str, version: str, variant: str, init_status: str
     ) -> None:
         self.ui.nk3_path.setText(path)
         self.ui.nk3_uuid.setText(uuid)
@@ -479,14 +446,10 @@ class SettingsTab(QtUtilsMixIn, QWidget):
         has_pin = fido_state.options["clientPin"]
 
         if state in [State.Fido, State.FidoReset]:
-
             self.update_status_form(
                 [
                     ("PIN set", "yes" if has_pin else "no"),
-                    (
-                        "PIN retries",
-                        str(pin_retries) if has_pin else "n/a",
-                    ),
+                    ("PIN retries", str(pin_retries) if has_pin else "n/a"),
                     ("Versions", ", ".join(fido_state.versions)),
                     ("Extensions", ", ".join(fido_state.extensions)),
                 ]
@@ -495,18 +458,13 @@ class SettingsTab(QtUtilsMixIn, QWidget):
             self.show_current_password(has_pin)
             self.ui.status_form.hide()
 
-    @Slot(SelectResponse)
+    @Slot(bool, SelectResponse)
     def handle_info_passwords(self, pin_set: bool, status: SelectResponse) -> None:
-
         if self.active_item is None:
             return
 
         state = self.active_item.data(1, 0)
-        if state in [
-            State.Passwords,
-            State.PasswordsReset,
-        ]:
-
+        if state in [State.Passwords, State.PasswordsReset]:
             data = [
                 ("PIN set", "yes" if pin_set else "no"),
                 ("PIN retries", str(status.pin_attempt_counter)),
@@ -518,7 +476,7 @@ class SettingsTab(QtUtilsMixIn, QWidget):
             self.update_status_form(data)
             self.show_current_password(pin_set)
 
-        elif state == State.PasswordsReset:
+        elif state == State.PasswordsPin:
             self.show_current_password(pin_set)
             self.ui.status_form.hide()
 
